# PhyloMICOM
PhyloMICOM is an extension of the MICOM package, designed to improve the accuracy and efficiency of microbial community simulations by incorporating phylogenetic relationships. This project introduces a modified version of the community.py file from the MICOM package, along with additional scripts and data for analysis.

<h3 style="font-size: 16px;">micom Folder</h3>
This folder contains the original MICOM package, with a key modification to the community.py file. The modification, known as PhyloMICOM, pools the metabolic models of phylogenetically related organisms at the order level. This allows for more accurate and phylogenetically-informed simulations of microbial communities.


<div>
  <pre>
    <code>
from micom import load_pickle
from micom.workflows import build
from micom.data import test_medium
from micom.qiime_formats import load_qiime_medium
<h3 style="font-size: 16px;">Building community models:</h3>
manifest = build(data, out_folder="models", model_db=test_db, cutoff=0.0001, threads=2)
<h3 style="font-size: 16px;">Perform a community simulation:</h3>
medium = load_qiime_medium('western_diet_gut.qza')
growth_results = grow(manifest, model_folder="models", medium=medium, tradeoff=0.5, threads=2)
    </code>
  </pre>
  <button onclick="copyCode()"></button>
</div>

<h3 style="font-size: 16px;">analysis Folder</h3>

This folder includes a collection of Python scripts used to analyze microbial communities. These scripts are tailored to work with the PhyloMICOM framework and provide tools for various types of analyses, such as sensitivity testing, growth rate prediction, and statistical evaluations.

<h3 style="font-size: 16px;">data Folder</h3>

The data folder contains all the input datasets used for running simulations and the corresponding output data generated by PhyloMICOM. This includes metagenomic data, configuration files, and simulation results. The input data is structured to be easily accessible for rerunning or extending the analyses performed in this project.

<h3 style="font-size: 16px;">license</h3>
PhyloMICOM is developed for non-commercial use and is provided as-is. Contributions are welcome and appreciated. For inquiries about collaborations or commercial usage and development, please contact us at s.mofidifar@gmail.com
